<?php
$TRANSLATIONS = array(
"This file is too big to be opened. Please download the file instead." => "این فایل برای باز کردن بسیار بزرگ است. لطفا آنرا دانلود کنید.",
"Cannot read the file." => "امکان خواندن فایل وجود ندارد",
"Invalid file path supplied." => "مسیر فایل نامعتبر است.",
"Cannot save file as it has been modified since opening" => "با توجه به تغییرات رخ داده بر روی فایل از زمان باز شدن آن، امکان ذخیره‌سازی وجود ندارد.",
"Insufficient permissions" => "دسترسی کافی نیست",
"File path not supplied" => "مسیر فایل داده نشده است",
"File mtime not supplied" => "mtime فایل داده نشده است",
"saving..." => "درحال ذخیره",
"saved!" => "ذخیره شد",
"failed!" => "ناموفق!",
"Saved" => "ذخیره شد",
"There was a problem saving your changes. Click to resume editing." => "مشکلی در زمان ذخیره‌سازی تغییرات شما وجود داشت. برای ادامه ویرایش کلیک کنید.",
"An error occurred!" => "یک خطا رخ‌داده است!",
"Text file" => "فایل متنی"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
